# Robocorp-Planhat: A Planhat API SDK integrated with Robocorp's Python Automation Framework

This automation library is designed for use with [Robocorp's Python Automation Framework](https://github.com/robocorp/robo). It includes data modeling for the base Planhat API object types and a customized client and associated session for use in authenticating, retrieving, and updating those objects.

## Installation

This project should be installed via your `conda.yaml` within a Robocorp automation task package under your pip dependancies.

## Experimental

**WARNING**: This library is currently experimental and missing several features such as full unit tests and documentation.